# powerxrd
A Python package made to handle powder XRD (and XRD) data. 
The only known open-source Github project with a Rietveld refinement method in development. 

<img src="https://raw.githubusercontent.com/andrewrgarcia/powerxrd/main/powerxrd.svg" width="400">


## Installation

```bash
pip install powerxrd
```

## Just starting? Check out the below options

<a href="https://powerxrd.readthedocs.io/en/latest">
<img src="https://raw.githubusercontent.com/andrewrgarcia/voxelmap/main/docs/img/readthedocs.png?raw=true" width="250" ></a>

<a href="https://colab.research.google.com/drive/1_Eq-cW6LSPPnaRjkbeHaC81Wfbd8mQS-?usp=sharing">
<img src="https://raw.githubusercontent.com/andrewrgarcia/powerxrd/main/docs/img/colaboratory.svg?raw=true" width="300" ></a>


## Contributing

1. Fork it (<https://github.com/your-github-user/powerxrd/fork>)
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request

